Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(713)

Unified Diff: ios/web/web_state/navigation_context_impl_unittest.mm

Issue 2759613003: Use SameDocument instead of SamePage term on iOS. (Closed)
Patch Set: Actually fixed tests Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ios/web/web_state/navigation_context_impl.mm ('k') | ios/web/web_state/ui/crw_web_controller.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ios/web/web_state/navigation_context_impl_unittest.mm
diff --git a/ios/web/web_state/navigation_context_impl_unittest.mm b/ios/web/web_state/navigation_context_impl_unittest.mm
index c9c8a87b830b700947b7b9f84c6ce6630455784b..558a308caa510fa28f19c624132fc552b96337b6 100644
--- a/ios/web/web_state/navigation_context_impl_unittest.mm
+++ b/ios/web/web_state/navigation_context_impl_unittest.mm
@@ -31,10 +31,11 @@ TEST_F(NavigationContextImplTest, NavigationContext) {
EXPECT_FALSE(context->IsErrorPage());
}
-// Tests CreateSamePageNavigationContext factory method.
-TEST_F(NavigationContextImplTest, SamePageNavigationContext) {
+// Tests CreateSameDocumentNavigationContext factory method.
+TEST_F(NavigationContextImplTest, SameDocumentNavigationContext) {
std::unique_ptr<NavigationContext> context =
- NavigationContextImpl::CreateSamePageNavigationContext(&web_state_, url_);
+ NavigationContextImpl::CreateSameDocumentNavigationContext(&web_state_,
+ url_);
ASSERT_TRUE(context);
EXPECT_EQ(&web_state_, context->GetWebState());
« no previous file with comments | « ios/web/web_state/navigation_context_impl.mm ('k') | ios/web/web_state/ui/crw_web_controller.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698